@@ -4,6 +4,7 @@ import importlib
 import logging
 from asyncdb.providers import BaseProvider
 from asyncdb.utils import colors, SafeDict, Msg
+from asyncdb.utils.functions import _escapeString, _quoteString
 from asyncdb.utils.models import Entity, Model
 from asyncdb.utils.encoders import BaseEncoder
 from asyncdb.exceptions import StatementError
@@ -24,24 +25,26 @@ from asyncdb.utils import (
     _escapeString,
 )
 
+
 class baseCursor:
     """
     baseCursor.
 
     Iterable Object for Cursor-Like functionality
     """
+
     _cursor = None
     _connection = None
     _provider: BaseProvider = None
     _result: Any = None
-    _sentence: str = ''
+    _sentence: str = ""
 
     def __init__(
         self,
-        provider:BaseProvider,
-        sentence:str,
+        provider: BaseProvider,
+        sentence: str,
         result: Optional[List] = None,
-        parameters: Iterable[Any] = None
+        parameters: Iterable[Any] = None,
     ):
         self._provider = provider
         self._result = result
@@ -51,9 +54,7 @@ class baseCursor:
 
     async def __aenter__(self) -> "baseCursor":
         self._cursor = await self._connection.cursor()
-        await self._cursor.execute(
-            self._sentence, self._params
-        )
+        await self._cursor.execute(self._sentence, self._params)
         return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb) -> None:
@@ -87,6 +88,7 @@ class SQLProvider(BaseProvider):
 
     Driver methods for SQL-based providers
     """
+
     _syntax = "sql"
     _test_query = "SELECT 1"
     _prepared = None
@@ -94,16 +96,15 @@ class SQLProvider(BaseProvider):
     _query_raw = "SELECT {fields} FROM {table} {where_cond}"
     __cursor__ = None
 
-
     def __init__(self, dsn="", loop=None, params={}, **kwargs):
         try:
             # dynamic loading of Cursor Class
-            cls = f'asyncdb.providers.{self._provider}'
-            cursor = f'{self._provider}Cursor'
+            cls = f"asyncdb.providers.{self._provider}"
+            cursor = f"{self._provider}Cursor"
             module = importlib.import_module(cls, package="providers")
             self.__cursor__ = getattr(module, cursor)
         except ImportError as err:
-            print('Error Loading Cursor Class: ', err)
+            print("Error Loading Cursor Class: ", err)
             pass
         super(SQLProvider, self).__init__(dsn=dsn, loop=loop, params=params, **kwargs)
 
@@ -135,9 +136,7 @@ class SQLProvider(BaseProvider):
             if self._connection:
                 if self._cursor:
                     await self._cursor.close()
-                await asyncio.wait_for(
-                    self._connection.close(), timeout=timeout
-                )
+                await asyncio.wait_for(self._connection.close(), timeout=timeout)
         except Exception as err:
             raise ProviderError("{}: Closing Error: {}".format(__name__, str(err)))
         finally:
@@ -159,7 +158,6 @@ class SQLProvider(BaseProvider):
         """
         await self.close()
 
-
     async def valid_operation(self, sentence: str):
         self._result = None
         if not sentence:
@@ -167,7 +165,6 @@ class SQLProvider(BaseProvider):
         if not self._connection:
             await self.connection()
 
-
     def cursor(self, sentence: str, parameters: Iterable[Any] = None) -> Iterable:
         """ Returns a iterable Cursor Object """
         if not sentence:
@@ -225,16 +222,13 @@ class SQLProvider(BaseProvider):
                             where_cond.append("%s != %s" % (key[:-1], value))
                         else:
                             if (
-                                type(value) == str and value.startswith("'")
+                                type(value) == str
+                                and value.startswith("'")
                                 and value.endswith("'")
                             ):
-                                where_cond.append(
-                                    "%s = %s" % (key, "{}".format(value))
-                                )
+                                where_cond.append("%s = %s" % (key, "{}".format(value)))
                             elif type(value) == int:
-                                where_cond.append(
-                                    "%s = %s" % (key, "{}".format(value))
-                                )
+                                where_cond.append("%s = %s" % (key, "{}".format(value)))
                             else:
                                 where_cond.append(
                                     "%s = %s" % (key, "'{}'".format(value))
@@ -245,9 +239,7 @@ class SQLProvider(BaseProvider):
                     else:
                         val = ",".join(map(str, value))
                         if type(val) == str and "'" not in val:
-                            where_cond.append(
-                                "%s IN (%s)" % (key, "'{}'".format(val))
-                            )
+                            where_cond.append("%s IN (%s)" % (key, "'{}'".format(val)))
                         else:
                             where_cond.append("%s IN (%s)" % (key, val))
                 # if 'WHERE ' in sentence:
@@ -285,9 +277,7 @@ class SQLProvider(BaseProvider):
         """
         if sentence:
             if type(ordering) == str:
-                return "{q} ORDER BY {ordering}".format(
-                    q=sentence, ordering=ordering
-                )
+                return "{q} ORDER BY {ordering}".format(q=sentence, ordering=ordering)
             elif type(ordering) == list:
                 return "{q} ORDER BY {ordering}".format(
                     q=sentence, ordering=", ".join(ordering)
@@ -368,39 +358,43 @@ class SQLProvider(BaseProvider):
     filter, get_one, get_any, get_all, create, update, delete, insert, remove
     """
 
-    def _where(self, fields:list, **where):
+    def _where(self, fields: list, **where):
         """
         TODO: add conditions for BETWEEN, NOT NULL, NULL, etc
         """
-        result = ''
+        result = ""
         if not where:
             return result
         elif type(where) == str:
-            result = 'WHERE {}'.format(where)
+            result = "WHERE {}".format(where)
         elif type(where) == dict:
             where_cond = []
             for key, value in where.items():
-                #print('HERE> ', fields)
+                # print('HERE> ', fields)
                 f = fields[key]
                 datatype = f.type
-                if value is None or value == 'null' or value == 'NULL':
-                    where_cond.append(f'{key} is NULL')
-                elif value == '!null' or value == '!NULL':
-                    where_cond.append(f'{key} is NOT NULL')
+                if value is None or value == "null" or value == "NULL":
+                    where_cond.append(f"{key} is NULL")
+                elif value == "!null" or value == "!NULL":
+                    where_cond.append(f"{key} is NOT NULL")
                 elif type(value) == bool:
                     val = str(value)
-                    where_cond.append(f'{key} is {value}')
+                    where_cond.append(f"{key} is {value}")
                 elif isinstance(datatype, List):
-                    val = ', '.join(map(str, [Entity.escapeLiteral(v, type(v)) for v in value]))
-                    where_cond.append(f'ARRAY[{val}]<@ {key}::character varying[]')
+                    val = ", ".join(
+                        map(str, [Entity.escapeLiteral(v, type(v)) for v in value])
+                    )
+                    where_cond.append(f"ARRAY[{val}]<@ {key}::character varying[]")
                 elif Entity.is_array(datatype):
-                    val = ', '.join(map(str, [Entity.escapeLiteral(v, type(v)) for v in value]))
-                    where_cond.append(f'{key} IN ({val})')
+                    val = ", ".join(
+                        map(str, [Entity.escapeLiteral(v, type(v)) for v in value])
+                    )
+                    where_cond.append(f"{key} IN ({val})")
                 else:
                     # is an scalar value
                     val = Entity.escapeLiteral(value, datatype)
-                    where_cond.append(f'{key}={val}')
-            result = '\nWHERE %s' % (' AND '.join(where_cond))
+                    where_cond.append(f"{key}={val}")
+            result = "\nWHERE %s" % (" AND ".join(where_cond))
             return result
         else:
             return result
@@ -412,7 +406,7 @@ class SQLProvider(BaseProvider):
         if not self._connection:
             await self.connection()
         result = None
-        tablename = f'{model.Meta.schema}.{model.Meta.name}'
+        tablename = f"{model.Meta.schema}.{model.Meta.name}"
         source = []
         pk = {}
         cols = []
@@ -423,7 +417,7 @@ class SQLProvider(BaseProvider):
             if field.primary_key is True:
                 pk[column] = value
         # TODO: work in an "update, delete, insert" functions on asyncdb to abstract data-insertion
-        sql = 'DELETE FROM {table} {condition}'
+        sql = "DELETE FROM {table} {condition}"
         condition = self._where(fields, **pk)
         sql = sql.format_map(SafeDict(table=tablename))
         sql = sql.format_map(SafeDict(condition=condition))
@@ -432,7 +426,9 @@ class SQLProvider(BaseProvider):
             # DELETE 1
         except Exception as err:
             print(traceback.format_exc())
-            raise Exception('Error on Delete over table {}: {}'.format(model.Meta.name, err))
+            raise Exception(
+                "Error on Delete over table {}: {}".format(model.Meta.name, err)
+            )
         return result
 
     async def insert(self, model: Model, fields: list = [], **kwargs):
@@ -442,7 +438,9 @@ class SQLProvider(BaseProvider):
         # TODO: option for returning more fields than PK in returning
         if not self._connection:
             await self.connection()
-        table = '{schema}.{table}'.format(table=model.Meta.name, schema=model.Meta.schema)
+        table = "{schema}.{table}".format(
+            table=model.Meta.name, schema=model.Meta.schema
+        )
         cols = []
         source = []
         pk = []
@@ -456,7 +454,7 @@ class SQLProvider(BaseProvider):
                 value = json.loads(json.dumps(asdict(val), cls=BaseEncoder))
             else:
                 value = val
-            if field.required is False and value is None or value == 'None':
+            if field.required is False and value is None or value == "None":
                 default = field.default
                 if callable(default):
                     value = default()
@@ -468,11 +466,11 @@ class SQLProvider(BaseProvider):
             if field.primary_key is True:
                 pk.append(column)
         try:
-            primary = 'RETURNING {}'.format(','.join(pk)) if pk else ''
-            columns = ','.join(cols)
-            values = ','.join(['${}'.format(a) for a in range(1,n)])
-            insert = f'INSERT INTO {table} ({columns}) VALUES({values}) {primary}'
-            logging.debug(f'INSERT: {insert}')
+            primary = "RETURNING {}".format(",".join(pk)) if pk else ""
+            columns = ",".join(cols)
+            values = ",".join(["${}".format(a) for a in range(1, n)])
+            insert = f"INSERT INTO {table} ({columns}) VALUES({values}) {primary}"
+            logging.debug(f"INSERT: {insert}")
             stmt = await self._connection.prepare(insert)
             result = await stmt.fetchrow(*source, timeout=2)
             logging.debug(stmt.get_statusmsg())
@@ -482,10 +480,12 @@ class SQLProvider(BaseProvider):
                     setattr(model, f, result[f])
                 return result
         except asyncpg.exceptions.UniqueViolationError as err:
-            raise StatementError('Constraint Error: {}'.format(err))
+            raise StatementError("Constraint Error: {}".format(err))
         except Exception as err:
             print(traceback.format_exc())
-            raise Exception('Error on Insert over table {}: {}'.format(model.Meta.name, err))
+            raise Exception(
+                "Error on Insert over table {}: {}".format(model.Meta.name, err)
+            )
 
     async def save(self, model: Model, fields: list = [], **kwargs):
         """
@@ -494,7 +494,7 @@ class SQLProvider(BaseProvider):
         """
         if not self._connection:
             await self.connection()
-        table = f'{model.Meta.schema}.{model.Meta.name}'
+        table = f"{model.Meta.schema}.{model.Meta.name}"
         source = []
         pk = {}
         values = []
@@ -502,34 +502,39 @@ class SQLProvider(BaseProvider):
         for name, field in fields.items():
             column = field.name
             datatype = field.type
-            dbtype = field.get_dbtype()
+            # try:
+            #     dbtype = field.get_dbtype()
+            # except AttributeError:
+            #     dbtype = ''
             value = getattr(model, field.name)
-            source.append('{} = {}'.format(
-                name,
-                '${}'.format(n))
-            )
+            source.append("{} = {}".format(name, "${}".format(n)))
             values.append(value)
-            n+=1
-            if field.primary_key is True:
-                pk[column] = value
+            n += 1
+            try:
+                if field.primary_key is True:
+                    pk[column] = value
+            except AttributeError:
+                pass
         # TODO: work in an "update, delete, insert" functions on asyncdb to abstract data-insertion
-        sql = 'UPDATE {table} SET {set_fields} {condition}'
+        sql = "UPDATE {table} SET {set_fields} {condition}"
         condition = self._where(fields, **pk)
         sql = sql.format_map(SafeDict(table=table))
         sql = sql.format_map(SafeDict(condition=condition))
         # set the columns
-        sql = sql.format_map(SafeDict(set_fields=', '.join(source)))
+        sql = sql.format_map(SafeDict(set_fields=", ".join(source)))
         print(sql)
         try:
             logging.debug(sql)
             stmt = await self._connection.prepare(sql)
             result = await stmt.fetchrow(*values, timeout=2)
             logging.debug(stmt.get_statusmsg())
-            #result = await self._connection.fetchrow(sql)
+            # result = await self._connection.fetchrow(sql)
             return result
         except Exception as err:
             print(traceback.format_exc())
-            raise Exception('Error on Insert over table {}: {}'.format(model.Meta.name, err))
+            raise Exception(
+                "Error on Insert over table {}: {}".format(model.Meta.name, err)
+            )
 
     async def get_all(self, model: Model, **kwargs):
         """
@@ -537,8 +542,8 @@ class SQLProvider(BaseProvider):
         """
         if not self._connection:
             await self.connection()
-        table = f'{model.Meta.schema}.{model.Meta.name}'
-        sql = f'SELECT * FROM {table}'
+        table = f"{model.Meta.schema}.{model.Meta.name}"
+        sql = f"SELECT * FROM {table}"
         try:
             prepared, error = await self.prepare(sql)
             result = await self._connection.fetch(sql)
@@ -546,18 +551,18 @@ class SQLProvider(BaseProvider):
         except Exception as err:
             print(traceback.format_exc())
             raise Exception(
-                'Error on Insert over table {}: {}'.format(
-                    model.Meta.name, err)
-                )
+                "Error on Insert over table {}: {}".format(model.Meta.name, err)
+            )
 
     async def get_one(self, model: Model, **kwargs):
         # if not self._connection:
         #     await self.connection()
-        table = f'{model.Meta.schema}.{model.Meta.name}'
+        table = f"{model.Meta.schema}.{model.Meta.name}"
         pk = {}
         cols = []
         source = []
         fields = model.columns(model)
+        # print(fields)
         for name, field in fields.items():
             val = getattr(model, field.name)
             # print(name, field, val)
@@ -565,24 +570,26 @@ class SQLProvider(BaseProvider):
             datatype = field.type
             value = Entity.toSQL(val, datatype)
             cols.append(column)
-            if field.primary_key is True:
-                pk[column] = value
-        columns = ', '.join(cols)
+            try:
+                if field.primary_key is True:
+                    pk[column] = value
+            except AttributeError:
+                pass
+        columns = ", ".join(cols)
         condition = self._where(fields, **kwargs)
-        sql = f'SELECT {columns} FROM {table} {condition}'
+        sql = f"SELECT {columns} FROM {table} {condition}"
         try:
             return await self._connection.fetchrow(sql)
         except Exception as err:
             print(traceback.format_exc())
             raise Exception(
-                'Error on Get One over table {}: {}'.format(
-                    model.Meta.name, err)
-                )
+                "Error on Get One over table {}: {}".format(model.Meta.name, err)
+            )
 
     async def fetch_one(self, model: Model, fields: list = [], **kwargs):
         # if not self._connection:
         #     await self.connection()
-        table = f'{model.Meta.schema}.{model.Meta.name}'
+        table = f"{model.Meta.schema}.{model.Meta.name}"
         pk = {}
         cols = []
         source = {}
@@ -590,30 +597,32 @@ class SQLProvider(BaseProvider):
             value = getattr(model, field.name)
             column = field.name
             cols.append(column)
-            if field.primary_key is True:
-                pk[column] = value
-        columns = ', '.join(cols)
+            try:
+                if field.primary_key is True:
+                    pk[column] = value
+            except AttributeError:
+                pass
+        columns = ", ".join(cols)
         arguments = {**pk, **kwargs}
         condition = self._where(fields=fields, **arguments)
         # migration of where to prepared statement
-        sql = f'SELECT {columns} FROM {table} {condition}'
+        sql = f"SELECT {columns} FROM {table} {condition}"
         try:
             return await self._connection.fetchrow(sql)
         except Exception as err:
             print(traceback.format_exc())
             raise Exception(
-                'Error on Get One over table {}: {}'.format(
-                    model.Meta.name, err)
-                )
+                "Error on Get One over table {}: {}".format(model.Meta.name, err)
+            )
 
-    async def select(self, model: Model, fields:list = [], **kwargs):
+    async def select(self, model: Model, fields: list = [], **kwargs):
         if not self._connection:
             await self.connection()
         pk = {}
         cols = []
         source = {}
-        print('HERE: ', model.__dict__)
-        table = f'{model.Meta.schema}.{model.Meta.name}'
+        # print('HERE: ', model.__dict__)
+        table = f"{model.Meta.schema}.{model.Meta.name}"
         for name, field in fields.items():
             column = field.name
             datatype = field.type
@@ -623,17 +632,19 @@ class SQLProvider(BaseProvider):
                 source[column] = Entity.toSQL(value, datatype)
             # if field.primary_key is True:
             #     pk[column] = value
-        columns = ', '.join(cols)
+        columns = ", ".join(cols)
         arguments = {**source, **kwargs}
-        print(arguments)
+        # print(arguments)
         condition = self._where(fields=fields, **arguments)
-        sql = f'SELECT {columns} FROM {table} {condition}'
+        sql = f"SELECT {columns} FROM {table} {condition}"
         print(sql)
         try:
             return await self._connection.fetch(sql)
         except Exception as err:
             print(traceback.format_exc())
-            raise Exception('Error on Insert over table {}: {}'.format(model.Meta.name, err))
+            raise Exception(
+                "Error on Insert over table {}: {}".format(model.Meta.name, err)
+            )
 
     async def filter(self, model: Model, **kwargs):
         if not self._connection:
@@ -641,21 +652,27 @@ class SQLProvider(BaseProvider):
         pk = {}
         cols = []
         fields = model.columns(model)
-        table = f'{model.Meta.schema}.{model.Meta.name}'
+        table = f"{model.Meta.schema}.{model.Meta.name}"
         for name, field in fields.items():
             column = field.name
             datatype = field.type
             cols.append(column)
-            if field.primary_key is True:
-                pk[column] = Entity.toSQL(getattr(model, field.name), datatype)
-        columns = ', '.join(cols)
+            try:
+                if field.primary_key is True:
+                    pk[column] = Entity.toSQL(getattr(model, field.name), datatype)
+            except AttributeError:
+                pass
+        columns = ", ".join(cols)
         condition = self._where(fields, **kwargs)
-        sql = f'SELECT {columns} FROM {table} {condition}'
+        sql = f"SELECT {columns} FROM {table} {condition}"
+        logging.debug(sql)
         try:
             return await self._connection.fetch(sql)
         except Exception as err:
             print(traceback.format_exc())
-            raise Exception('Error on Insert over table {}: {}'.format(model.Meta.name, err))
+            raise Exception(
+                "Error on Insert over table {}: {}".format(model.Meta.name, err)
+            )
 
     async def update_rows(self, model: Model, conditions: dict, **kwargs):
         """
@@ -663,7 +680,7 @@ class SQLProvider(BaseProvider):
         """
         if not self._connection:
             await self.connection()
-        table = f'{model.Meta.schema}.{model.Meta.name}'
+        table = f"{model.Meta.schema}.{model.Meta.name}"
         source = []
         pk = {}
         cols = []
@@ -674,27 +691,25 @@ class SQLProvider(BaseProvider):
             cols.append(column)
             if column in kwargs:
                 value = Entity.toSQL(kwargs[column], datatype)
-                source.append('{} = {}'.format(
-                    column,
-                    Entity.escapeLiteral(
-                        value, datatype
-                        )
-                    )
+                source.append(
+                    "{} = {}".format(column, Entity.escapeLiteral(value, datatype))
                 )
-        set_fields = ', '.join(source)
+        set_fields = ", ".join(source)
         condition = self._where(fields, **conditions)
-        columns = ', '.join(cols)
-        sql = f'UPDATE {table} SET {set_fields} {condition}'
-        print(sql)
+        columns = ", ".join(cols)
+        sql = f"UPDATE {table} SET {set_fields} {condition}"
+        logging.debug(sql)
         try:
             result = await self._connection.execute(sql)
             if result:
-                sql = f'SELECT {columns} FROM {table} {condition}'
-                print('UPDATE ', sql)
+                sql = f"SELECT {columns} FROM {table} {condition}"
+                print("UPDATE ", sql)
                 return await self._connection.fetch(sql)
         except Exception as err:
             print(traceback.format_exc())
-            raise Exception('Error on Insert over table {}: {}'.format(model.Meta.name, err))
+            raise Exception(
+                "Error on Insert over table {}: {}".format(model.Meta.name, err)
+            )
 
     async def delete_rows(self, model: Model, conditions: dict, **kwargs):
         """
@@ -702,7 +717,7 @@ class SQLProvider(BaseProvider):
         """
         if not self._connection:
             await self.connection()
-        table = f'{model.Meta.schema}.{model.Meta.name}'
+        table = f"{model.Meta.schema}.{model.Meta.name}"
         source = []
         pk = {}
         cols = []
@@ -713,25 +728,23 @@ class SQLProvider(BaseProvider):
             cols.append(column)
             if column in kwargs:
                 value = Entity.toSQL(kwargs[column], datatype)
-                source.append('{} = {}'.format(
-                    column,
-                    Entity.escapeLiteral(
-                        value, datatype
-                        )
-                    )
+                source.append(
+                    "{} = {}".format(column, Entity.escapeLiteral(value, datatype))
                 )
-        set_fields = ', '.join(source)
+        set_fields = ", ".join(source)
         condition = self._where(fields, **conditions)
-        columns = ', '.join(cols)
-        sql = f'DELETE FROM {table} {condition}'
-        print(sql)
+        columns = ", ".join(cols)
+        sql = f"DELETE FROM {table} {condition}"
+        logging.debug(sql)
         try:
             result = await self._connection.execute(sql)
             if result:
                 return result
         except Exception as err:
             print(traceback.format_exc())
-            raise Exception('Error on Deleting table {}: {}'.format(model.Meta.name, err))
+            raise Exception(
+                "Error on Deleting table {}: {}".format(model.Meta.name, err)
+            )
 
     async def create_rows(self, model: Model, rows: list):
         """
@@ -739,7 +752,7 @@ class SQLProvider(BaseProvider):
         """
         if not self._connection:
             await self.connection()
-        table = f'{model.Meta.schema}.{model.Meta.name}'
+        table = f"{model.Meta.schema}.{model.Meta.name}"
         fields = model.columns(model)
         results = []
         stmt = None
@@ -748,6 +761,7 @@ class SQLProvider(BaseProvider):
             pk = []
             cols = []
             for col, field in fields.items():
+                print("HERE ", col, field)
                 if col not in row:
                     # field doesnt exists
                     default = field.default
@@ -763,9 +777,7 @@ class SQLProvider(BaseProvider):
                         #     source.append(val)
                         # elif field.required is True or field.primary_key is True:
                         if field.required is True:
-                            raise StatementError(
-                                f'Missing Required Field: {col}'
-                            )
+                            raise StatementError(f"Missing Required Field: {col}")
                 else:
                     try:
                         val = row[col]
@@ -773,33 +785,36 @@ class SQLProvider(BaseProvider):
                         cols.append(col)
                     except (KeyError, TypeError):
                         continue
-                if field.primary_key is True:
-                    pk.append(col)
+                try:
+                    if field.primary_key is True:
+                        pk.append(col)
+                except AttributeError:
+                    pass
             if not stmt:
-                columns = ', '.join(cols)
+                columns = ", ".join(cols)
                 n = len(cols)
-                values = ','.join(['${}'.format(a) for a in range(1, n+1)])
-                primary = 'RETURNING *'
-                insert = f'INSERT INTO {table} ({columns}) VALUES ({values}) {primary}'
-                print(insert)
-                logging.debug(f'INSERT: {insert}')
+                values = ",".join(["${}".format(a) for a in range(1, n + 1)])
+                primary = "RETURNING *"
+                insert = f"INSERT INTO {table} ({columns}) VALUES ({values}) {primary}"
+                logging.debug(f"INSERT: {insert}")
                 try:
                     stmt = await self._connection.prepare(insert)
                 except Exception as err:
                     print(traceback.format_exc())
                     raise Exception(
-                        'Exception creating Prepared Sentence {}: {}'.format(
-                            model.Meta.name, err)
+                        "Exception creating Prepared Sentence {}: {}".format(
+                            model.Meta.name, err
                         )
+                    )
             try:
                 result = await stmt.fetchrow(*source, timeout=2)
                 logging.debug(stmt.get_statusmsg())
                 if result:
                     results.append(result)
             except asyncpg.exceptions.UniqueViolationError as err:
-                raise StatementError('Constraint Error: {}'.format(err))
+                raise StatementError("Constraint Error: {}".format(err))
             except Exception as err:
                 print(traceback.format_exc())
-                raise Exception('Error Bulk Insert {}: {}'.format(table, err))
+                raise Exception("Error Bulk Insert {}: {}".format(table, err))
         else:
             return results
