@@ -38,6 +38,7 @@ class SafeDict(dict):
     Allow to using partial format strings
 
     """
+
     def __missing__(self, key):
         """Missing method for SafeDict."""
         return "{" + key + "}"
@@ -49,6 +50,13 @@ def _escapeString(value):
     v = "'{}'".format(v) if type(v) == str else v
     return v
 
+
+def _quoteString(value):
+    v = value if value != "None" else ""
+    v = "'{}'".format(v) if type(v) == str else v
+    return v
+
+
 def generate_key():
     return binascii.hexlify(os.urandom(20)).decode()
 
@@ -132,8 +140,7 @@ def fdom():
 
 
 def ldom():
-    return (datetime.datetime.now() +
-            relativedelta(day=31)).strftime("%Y-%m-%d")
+    return (datetime.datetime.now() + relativedelta(day=31)).strftime("%Y-%m-%d")
 
 
 def now():
@@ -271,7 +278,8 @@ def extract_string(value, exp=r"_((\d+)_(\d+))_", group=1, parsedate=False):
     if match:
         result = (
             match.group(group)
-            if not parsedate else dateparser.parse(match.group(group))
+            if not parsedate
+            else dateparser.parse(match.group(group))
         )
         return result
 
@@ -437,9 +445,12 @@ def get_program_date(value, yesterday: bool = False, *args):
         else:
             return opt
 
+
 """
 Module Loading
 """
+
+
 def module_exists(module_name, classpath):
     try:
         # try to using importlib
@@ -452,12 +463,8 @@ def module_exists(module_name, classpath):
             obj = __import__(classpath, fromlist=[module_name])
             return obj
         except ImportError:
-            logging.exception(
-                f"No Driver for provider {module_name} was found"
-            )
-            raise ImportError(
-                message=f"No Provider {module_name} Found"
-            )
+            logging.exception(f"No Driver for provider {module_name} was found")
+            raise ImportError(message=f"No Provider {module_name} Found")
 
 
 class colors:
@@ -471,13 +478,13 @@ class colors:
     and invisible work with the main class i.e. colors.bold
     """
 
-    reset = '\033[0m'
-    bold = '\033[01m'
-    disable = '\033[02m'
-    underline = '\033[04m'
-    reverse = '\033[07m'
-    strikethrough = '\033[09m'
-    invisible = '\033[08m'
+    reset = "\033[0m"
+    bold = "\033[01m"
+    disable = "\033[02m"
+    underline = "\033[04m"
+    reverse = "\033[07m"
+    strikethrough = "\033[09m"
+    invisible = "\033[08m"
 
     class fg:
         """
@@ -486,49 +493,49 @@ class colors:
         Foreground Color subClass
         """
 
-        black = '\033[30m'
-        red = '\033[31m'
-        green = '\033[32m'
-        orange = '\033[33m'
-        blue = '\033[34m'
-        purple = '\033[35m'
-        cyan = '\033[36m'
-        lightgrey = '\033[37m'
-        darkgrey = '\033[90m'
-        lightred = '\033[91m'
-        lightgreen = '\033[92m'
-        yellow = '\033[93m'
-        lightblue = '\033[94m'
-        pink = '\033[95m'
-        lightcyan = '\033[96m'
+        black = "\033[30m"
+        red = "\033[31m"
+        green = "\033[32m"
+        orange = "\033[33m"
+        blue = "\033[34m"
+        purple = "\033[35m"
+        cyan = "\033[36m"
+        lightgrey = "\033[37m"
+        darkgrey = "\033[90m"
+        lightred = "\033[91m"
+        lightgreen = "\033[92m"
+        yellow = "\033[93m"
+        lightblue = "\033[94m"
+        pink = "\033[95m"
+        lightcyan = "\033[96m"
 
 
 class Msg(object):
-    def __init__(self, message: str = '', level: str = 'INFO'):
-        if level == 'INFO' or level == 'info':
+    def __init__(self, message: str = "", level: str = "INFO"):
+        if level == "INFO" or level == "info":
             coloring = colors.bold + colors.fg.green
-        elif level == 'DEBUG' or level == 'debug':
+        elif level == "DEBUG" or level == "debug":
             coloring = colors.fg.lightblue
-        elif level == 'WARN' or level == 'warning':
+        elif level == "WARN" or level == "warning":
             coloring = colors.bold + colors.fg.yellow
-        elif self.level == 'ERROR':
+        elif self.level == "ERROR":
             coloring = colors.fg.lightred
-        elif self.level == 'CRITICAL':
+        elif self.level == "CRITICAL":
             coloring = colors.bold + colors.fg.red
         else:
             coloring = colors.reset
         print(coloring + message, colors.reset)
 
-    def __call__(self, message: str = '', level: str = 'INFO', *args, **kwargs):
-        if level == 'INFO' or level == 'info':
+    def __call__(self, message: str = "", level: str = "INFO", *args, **kwargs):
+        if level == "INFO" or level == "info":
             coloring = colors.bold + colors.fg.green
-        elif level == 'DEBUG' or level == 'debug':
+        elif level == "DEBUG" or level == "debug":
             coloring = colors.fg.lightblue
-        elif level == 'WARN' or level == 'warning':
+        elif level == "WARN" or level == "warning":
             coloring = colors.bold + colors.fg.yellow
-        elif self.level == 'ERROR':
+        elif self.level == "ERROR":
             coloring = colors.fg.lightred
-        elif self.level == 'CRITICAL':
+        elif self.level == "CRITICAL":
             coloring = colors.bold + colors.fg.red
         else:
             coloring = colors.reset
